@@ -1,31 +1,27 @@
 """Helpers."""
+from __future__ import annotations
+
 import errno
-import hashlib
 import json
 import logging
 import os
 import os.path
 import sys
+from collections.abc import Callable, Hashable, Iterable
 from hashlib import md5
 from typing import (
-    Callable,
-    Dict,
-    Hashable,
-    Iterable,
-    Optional,
     TypeVar,
-    Union,
     cast,
 )
 
-from filelock import FileLock
 import requests
+from filelock import FileLock
 
 LOG = logging.getLogger(__name__)
 
 _DID_LOG_UNABLE_TO_CACHE = False
 
-T = TypeVar("T")  # pylint: disable=invalid-name
+T = TypeVar("T")
 
 
 def get_pkg_unique_identifier() -> str:
@@ -36,7 +32,6 @@ def get_pkg_unique_identifier() -> str:
     a new version of tldextract
     """
     try:
-        # pylint: disable=import-outside-toplevel
         from tldextract._version import version
     except ImportError:
         version = "dev"
@@ -44,9 +39,7 @@ def get_pkg_unique_identifier() -> str:
     tldextract_version = "tldextract-" + version
     python_env_name = os.path.basename(sys.prefix)
     # just to handle the edge case of two identically named python environments
-    python_binary_path_short_hash = hashlib.md5(sys.prefix.encode("utf-8")).hexdigest()[
-        :6
-    ]
+    python_binary_path_short_hash = md5(sys.prefix.encode("utf-8")).hexdigest()[:6]
     python_version = ".".join([str(v) for v in sys.version_info[:-1]])
     identifier_parts = [
         python_version,
@@ -88,7 +81,8 @@ def get_cache_dir() -> str:
 class DiskCache:
     """Disk _cache that only works for jsonable values."""
 
-    def __init__(self, cache_dir: Optional[str], lock_timeout: int = 20):
+    def __init__(self, cache_dir: str | None, lock_timeout: int = 20):
+        """Construct a disk cache in the given directory."""
         self.enabled = bool(cache_dir)
         self.cache_dir = os.path.expanduser(str(cache_dir) or "")
         self.lock_timeout = lock_timeout
@@ -96,8 +90,8 @@ class DiskCache:
         # combined with a call to `.clear()` wont wipe someones hard drive
         self.file_ext = ".tldextract.json"
 
-    def get(self, namespace: str, key: Union[str, Dict[str, Hashable]]) -> object:
-        """Retrieve a value from the disk cache"""
+    def get(self, namespace: str, key: str | dict[str, Hashable]) -> object:
+        """Retrieve a value from the disk cache."""
         if not self.enabled:
             raise KeyError("Cache is disabled")
         cache_filepath = self._key_to_cachefile_path(namespace, key)
@@ -105,15 +99,14 @@ class DiskCache:
         if not os.path.isfile(cache_filepath):
             raise KeyError("namespace: " + namespace + " key: " + repr(key))
         try:
-            # pylint: disable-next=unspecified-encoding
             with open(cache_filepath) as cache_file:
                 return json.load(cache_file)
         except (OSError, ValueError) as exc:
             LOG.error("error reading TLD cache file %s: %s", cache_filepath, exc)
             raise KeyError("namespace: " + namespace + " key: " + repr(key)) from None
 
-    def set(
-        self, namespace: str, key: Union[str, Dict[str, Hashable]], value: object
+    def set(  # noqa: A003
+        self, namespace: str, key: str | dict[str, Hashable], value: object
     ) -> None:
         """Set a value in the disk cache."""
         if not self.enabled:
@@ -123,11 +116,10 @@ class DiskCache:
 
         try:
             _make_dir(cache_filepath)
-            # pylint: disable-next=unspecified-encoding
             with open(cache_filepath, "w") as cache_file:
                 json.dump(value, cache_file)
         except OSError as ioe:
-            global _DID_LOG_UNABLE_TO_CACHE  # pylint: disable=global-statement
+            global _DID_LOG_UNABLE_TO_CACHE
             if not _DID_LOG_UNABLE_TO_CACHE:
                 LOG.warning(
                     "unable to cache %s.%s in %s. This could refresh the "
@@ -159,7 +151,7 @@ class DiskCache:
                             raise
 
     def _key_to_cachefile_path(
-        self, namespace: str, key: Union[str, Dict[str, Hashable]]
+        self, namespace: str, key: str | dict[str, Hashable]
     ) -> str:
         namespace_path = os.path.join(self.cache_dir, namespace)
         hashed_key = _make_cache_key(key)
@@ -172,7 +164,7 @@ class DiskCache:
         self,
         func: Callable[..., T],
         namespace: str,
-        kwargs: Dict[str, Hashable],
+        kwargs: dict[str, Hashable],
         hashed_argnames: Iterable[str],
     ) -> T:
         """Get a url but cache the response."""
@@ -185,7 +177,7 @@ class DiskCache:
         try:
             _make_dir(cache_filepath)
         except OSError as ioe:
-            global _DID_LOG_UNABLE_TO_CACHE  # pylint: disable=global-statement
+            global _DID_LOG_UNABLE_TO_CACHE
             if not _DID_LOG_UNABLE_TO_CACHE:
                 LOG.warning(
                     "unable to cache %s.%s in %s. This could refresh the "
@@ -201,8 +193,6 @@ class DiskCache:
 
             return func(**kwargs)
 
-        # Disable lint of 3rd party (see also https://github.com/tox-dev/py-filelock/issues/102)
-        # pylint: disable-next=abstract-class-instantiated
         with FileLock(lock_path, timeout=self.lock_timeout):
             try:
                 result = cast(T, self.get(namespace=namespace, key=key_args))
@@ -213,7 +203,7 @@ class DiskCache:
             return result
 
     def cached_fetch_url(
-        self, session: requests.Session, url: str, timeout: Union[float, int, None]
+        self, session: requests.Session, url: str, timeout: float | int | None
     ) -> str:
         """Get a url but cache the response."""
         return self.run_and_cache(
@@ -224,7 +214,7 @@ class DiskCache:
         )
 
 
-def _fetch_url(session: requests.Session, url: str, timeout: Optional[int]) -> str:
+def _fetch_url(session: requests.Session, url: str, timeout: int | None) -> str:
     response = session.get(url, timeout=timeout)
     response.raise_for_status()
     text = response.text
@@ -235,7 +225,7 @@ def _fetch_url(session: requests.Session, url: str, timeout: Optional[int]) -> s
     return text
 
 
-def _make_cache_key(inputs: Union[str, Dict[str, Hashable]]) -> str:
+def _make_cache_key(inputs: str | dict[str, Hashable]) -> str:
     key = repr(inputs)
     return md5(key.encode("utf8")).hexdigest()
 
